@@ -23,28 +23,28 @@ from datamodel_code_generator.types import DataType, Types
             Types.integer,
             {'maximum': 10},
             DataType(
-                type='conint', is_func=True, kwargs={'le': 10}, imports=[IMPORT_CONINT]
+                type='conint', is_func=True, kwargs={'le': 10}, import_=IMPORT_CONINT
             ),
         ),
         (
             Types.integer,
             {'exclusiveMaximum': 10},
             DataType(
-                type='conint', is_func=True, kwargs={'lt': 10}, imports=[IMPORT_CONINT]
+                type='conint', is_func=True, kwargs={'lt': 10}, import_=IMPORT_CONINT
             ),
         ),
         (
             Types.integer,
             {'minimum': 10},
             DataType(
-                type='conint', is_func=True, kwargs={'ge': 10}, imports=[IMPORT_CONINT]
+                type='conint', is_func=True, kwargs={'ge': 10}, import_=IMPORT_CONINT
             ),
         ),
         (
             Types.integer,
             {'exclusiveMinimum': 10},
             DataType(
-                type='conint', is_func=True, kwargs={'gt': 10}, imports=[IMPORT_CONINT]
+                type='conint', is_func=True, kwargs={'gt': 10}, import_=IMPORT_CONINT
             ),
         ),
         (
@@ -54,23 +54,25 @@ from datamodel_code_generator.types import DataType, Types
                 type='conint',
                 is_func=True,
                 kwargs={'multiple_of': 10},
-                imports=[IMPORT_CONINT],
+                import_=IMPORT_CONINT,
             ),
         ),
         (
             Types.integer,
             {'exclusiveMinimum': 0},
-            DataType(type='PositiveInt', imports=[IMPORT_POSITIVE_INT]),
+            DataType(type='PositiveInt', import_=IMPORT_POSITIVE_INT),
         ),
         (
             Types.integer,
             {'exclusiveMaximum': 0},
-            DataType(type='NegativeInt', imports=[IMPORT_NEGATIVE_INT]),
+            DataType(type='NegativeInt', import_=IMPORT_NEGATIVE_INT),
         ),
     ],
 )
 def test_get_data_int_type(types, params, data_type):
-    assert DataTypeManager().get_data_int_type(types, **params) == data_type
+    assert (
+        DataTypeManager().get_data_int_type(types, **params).dict() == data_type.dict()
+    )
 
 
 @pytest.mark.parametrize(
@@ -84,7 +86,7 @@ def test_get_data_int_type(types, params, data_type):
                 type='confloat',
                 is_func=True,
                 kwargs={'le': 10},
-                imports=[IMPORT_CONFLOAT],
+                import_=IMPORT_CONFLOAT,
             ),
         ),
         (
@@ -94,7 +96,7 @@ def test_get_data_int_type(types, params, data_type):
                 type='confloat',
                 is_func=True,
                 kwargs={'lt': 10.0},
-                imports=[IMPORT_CONFLOAT],
+                import_=IMPORT_CONFLOAT,
             ),
         ),
         (
@@ -104,7 +106,7 @@ def test_get_data_int_type(types, params, data_type):
                 type='confloat',
                 is_func=True,
                 kwargs={'ge': 10.0},
-                imports=[IMPORT_CONFLOAT],
+                import_=IMPORT_CONFLOAT,
             ),
         ),
         (
@@ -114,7 +116,7 @@ def test_get_data_int_type(types, params, data_type):
                 type='confloat',
                 is_func=True,
                 kwargs={'gt': 10.0},
-                imports=[IMPORT_CONFLOAT],
+                import_=IMPORT_CONFLOAT,
             ),
         ),
         (
@@ -124,18 +126,18 @@ def test_get_data_int_type(types, params, data_type):
                 type='confloat',
                 is_func=True,
                 kwargs={'multiple_of': 10.0},
-                imports=[IMPORT_CONFLOAT],
+                import_=IMPORT_CONFLOAT,
             ),
         ),
         (
             Types.float,
             {'exclusiveMinimum': 0},
-            DataType(type='PositiveFloat', imports=[IMPORT_POSITIVE_FLOAT]),
+            DataType(type='PositiveFloat', import_=IMPORT_POSITIVE_FLOAT),
         ),
         (
             Types.float,
             {'exclusiveMaximum': 0},
-            DataType(type='NegativeFloat', imports=[IMPORT_NEGATIVE_FLOAT]),
+            DataType(type='NegativeFloat', import_=IMPORT_NEGATIVE_FLOAT),
         ),
     ],
 )
@@ -150,7 +152,7 @@ def test_get_data_float_type(types, params, data_type):
             Types.decimal,
             {},
             DataType(
-                type='Decimal', imports=[Import(from_='decimal', import_='Decimal')]
+                type='Decimal', import_=Import(from_='decimal', import_='Decimal')
             ),
         ),
         (
@@ -160,7 +162,7 @@ def test_get_data_float_type(types, params, data_type):
                 type='condecimal',
                 is_func=True,
                 kwargs={'le': 10},
-                imports=[IMPORT_CONDECIMAL],
+                import_=IMPORT_CONDECIMAL,
             ),
         ),
         (
@@ -170,7 +172,7 @@ def test_get_data_float_type(types, params, data_type):
                 type='condecimal',
                 is_func=True,
                 kwargs={'lt': 10},
-                imports=[IMPORT_CONDECIMAL],
+                import_=IMPORT_CONDECIMAL,
             ),
         ),
         (
@@ -180,7 +182,7 @@ def test_get_data_float_type(types, params, data_type):
                 type='condecimal',
                 is_func=True,
                 kwargs={'ge': 10},
-                imports=[IMPORT_CONDECIMAL],
+                import_=IMPORT_CONDECIMAL,
             ),
         ),
         (
@@ -190,7 +192,7 @@ def test_get_data_float_type(types, params, data_type):
                 type='condecimal',
                 is_func=True,
                 kwargs={'gt': 10},
-                imports=[IMPORT_CONDECIMAL],
+                import_=IMPORT_CONDECIMAL,
             ),
         ),
         (
@@ -200,7 +202,7 @@ def test_get_data_float_type(types, params, data_type):
                 type='condecimal',
                 is_func=True,
                 kwargs={'multiple_of': 10},
-                imports=[IMPORT_CONDECIMAL],
+                import_=IMPORT_CONDECIMAL,
             ),
         ),
     ],
@@ -220,7 +222,7 @@ def test_get_data_decimal_type(types, params, data_type):
                 type='constr',
                 is_func=True,
                 kwargs={'regex': "r'^abc'"},
-                imports=[IMPORT_CONSTR],
+                import_=IMPORT_CONSTR,
             ),
         ),
         (
@@ -230,7 +232,7 @@ def test_get_data_decimal_type(types, params, data_type):
                 type='constr',
                 is_func=True,
                 kwargs={'min_length': 10},
-                imports=[IMPORT_CONSTR],
+                import_=IMPORT_CONSTR,
             ),
         ),
         (
@@ -240,7 +242,7 @@ def test_get_data_decimal_type(types, params, data_type):
                 type='constr',
                 is_func=True,
                 kwargs={'max_length': 10},
-                imports=[IMPORT_CONSTR],
+                import_=IMPORT_CONSTR,
             ),
         ),
     ],
@@ -260,7 +262,7 @@ def test_get_data_str_type(types, params, data_type):
             Types.decimal,
             {},
             DataType(
-                type='Decimal', imports=[Import(from_='decimal', import_='Decimal')]
+                type='Decimal', import_=Import(from_='decimal', import_='Decimal')
             ),
         ),
     ],
